==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/LinksAerialConsentRevoked.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObjectGrantAerialConsent;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LinksAerialConsentRevoked
 */
@JsonPropertyOrder({ LinksAerialConsentRevoked.JSON_PROPERTY_GRANT })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class LinksAerialConsentRevoked implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_GRANT = "grant";
    private HrefObjectGrantAerialConsent grant;

    public LinksAerialConsentRevoked() {
    }

    public LinksAerialConsentRevoked grant(HrefObjectGrantAerialConsent grant) {

        this.grant = grant;
        return this;
    }

    /**
     * Get grant
     *
     * @return grant
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_GRANT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectGrantAerialConsent getGrant() {
        return grant;
    }

    @JsonProperty(JSON_PROPERTY_GRANT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setGrant(HrefObjectGrantAerialConsent grant) {
        this.grant = grant;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LinksAerialConsentRevoked linksAerialConsentRevoked = (LinksAerialConsentRevoked) o;
        return Objects.equals(this.grant, linksAerialConsentRevoked.grant);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(grant);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LinksAerialConsentRevoked {\n");
        sb.append("    grant: ").append(toIndentedString(grant)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/LinksAerialConsentRevoked.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObjectGrantAerialConsent;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LinksAerialConsentRevoked
 */
@JsonPropertyOrder({ LinksAerialConsentRevoked.JSON_PROPERTY_GRANT })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class LinksAerialConsentRevoked implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_GRANT = "grant";
    private HrefObjectGrantAerialConsent grant;

    public LinksAerialConsentRevoked() {
    }

    public LinksAerialConsentRevoked grant(HrefObjectGrantAerialConsent grant) {

        this.grant = grant;
        return this;
    }

    /**
     * Get grant
     *
     * @return grant
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_GRANT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectGrantAerialConsent getGrant() {
        return grant;
    }

    @JsonProperty(JSON_PROPERTY_GRANT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setGrant(HrefObjectGrantAerialConsent grant) {
        this.grant = grant;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LinksAerialConsentRevoked linksAerialConsentRevoked = (LinksAerialConsentRevoked) o;
        return Objects.equals(this.grant, linksAerialConsentRevoked.grant);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(grant);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LinksAerialConsentRevoked {\n");
        sb.append("    grant: ").append(toIndentedString(grant)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
